@@ -1,4 +1,6 @@
 #[cfg(feature = "barrel-mysql")]
 pub(crate) mod mysql;
+#[cfg(feature = "barrel-pg")]
+pub(crate) mod pg;
 #[cfg(feature = "barrel-sqlite")]
 pub(crate) mod sqlite;
