@@ -1,4 +1,6 @@
 #[cfg(feature = "mysql")]
 pub(crate) mod mysql;
+#[cfg(feature = "pg")]
+pub(crate) mod pg;
 #[cfg(feature = "sqlite")]
 pub(crate) mod sqlite;
